@@ -6,7 +6,7 @@ import xml.etree.ElementTree as ET
 import saspy
 import logging
 import tempfile
-from src.ivanov.globals import all_obj_types
+from ..globals import all_obj_types
 from sys import platform
 
 
